function [bid,x]=bidbhg1(aleph,bet,tau,n)
%[bid,x]=BIDBHG1(alpha,beta,tau,n)
%  Returns equilibrium bidding strategy in first-price BHG model.
%  
%  Inputs:
%     (alpha, beta, tau, n) = model parameters (scalars)
%
%  Outputs:
%     (bid,x) = vectors from ODE solution of model
%
%  Requires: bdotbhg.m, bhgnulambda.mex

%  Michael Gordy <mgordy@frb.gov>  December 24, 1997

global alpha_ n_ tau_ beta_ 

% set up globals.  
alpha_=aleph; beta_=bet; tau_=tau; n_=n;

disp('BIDBHG1: Solving BHG 1st price model')
dstr='Parameters alpha=%6.4f,beta=%6.4f,tau=%2.0f,n=%2.0f';
disp(sprintf(dstr,[alpha_,beta_,tau_,n_]))

options=odeset('RelTol',1e-5,'Refine',10,'Vectorized','on');
[x,bid]=ode45('bdotbhg',[0 1],0,options);
