function [bid,x,xbid]=bidblsg1(aleph,bet,tau,n)
%[bid,x,xbid]=BIDBLSG1(alpha,beta,tau,n)
%  Returns equilibrium bidding strategy in first-price BLSG model.
%  
%  Inputs:
%     (alpha, beta, tau, n) = model parameters (scalars)
%
%  Outputs:
%     (bid,x,xbid) = vectors from ODE solution of model
%
%  Note:
%     The function Q(x)=x*B(x) is better behaved than B(x).  It starts
%     at Q(0)=0, and then is increasing and gently convex.  The output
%     "xbid" is this function Q.  The output "bid" is calculated from
%     xbid.
%
%  Requires: bdotxblsg.m, blsgnuxlambda.mex

%  Michael Gordy <mgordy@frb.gov>  July 15, 1997
%  See "Computationally Convenient Distributional Assumptions for Common
%  Value Auctions" by Michael B. Gordy, Federal Reserve Board Finance and
%  Economics Discussion Series, 1997-5, January 1997.

global alpha_ n_ tau_ beta_ 

% set up globals.  
alpha_=aleph; beta_=bet; tau_=tau; n_=n;

disp('BIDBLSG1: Solving BLSG 1st price model')
dstr='Parameters alpha=%6.4f,beta=%6.4f,tau=%2.0f,n=%2.0f';
disp(sprintf(dstr,[alpha_,beta_,tau_,n_]))

options=odeset('RelTol',1e-5,'Refine',10,'Vectorized','on');
[x,xbid]=ode45('bdotxblsg',[0 1],0,options);
bid=[0; xbid(2:end)./x(2:end)];
