function [bb,xx]=bidghg1(aleph,bet,tau,n)
%[bid,x]=BIDGHG1(alpha,beta,tau,n)
%  Returns equilibrium bidding strategy in first-price GHG model.
%  See gigbnlg.README
%
%  Inputs:
%     (alpha, beta, tau, n) = model parameters (scalars)
%
%  Outputs:
%     (bid,x) = vectors from ODE solution of model
%
%  Requires: bdotghg.m, ghgnulambda.mex, psi.mex

%  Michael Gordy <mgordy@frb.gov>  December 22, 1997

global alpha_ n_ tau_ beta_ 

% set up globals.  
alpha_=aleph; beta_=bet; tau_=tau; n_=n;

disp('BIDGHG1: Solving GHG 1st price model')
dstr='Parameters alpha=%6.4f,beta=%6.4f,tau=%2.0f,n=%2.0f';
disp(sprintf(dstr,[alpha_,beta_,tau_,n_]))
options=odeset('RelTol',1e-5,'Refine',10,'Vectorized','on');
[xx,bb]=ode23('bdotghg',[0 1],0,options);
