function [bb,xx]=bidgig1(aleph,bet,tau,n,xmax)
%[bid,x]=BIDGIG1(alpha,beta,tau,n,xmax)
%  Returns equilibrium bidding strategy in first-price GIG model.
%  
%  Inputs:
%     (alpha, beta, tau, n) = model parameters (scalars)
%     xmax = highest value of x (scalar)
%
%  Outputs:
%     (bid,x) = vectors from ODE solution of model
%
%  Requires: bdotgig.m, gignulambda.mex, psi.mex

%  Michael Gordy <mgordy@frb.gov>  October 3, 1997
%  See "Computationally Convenient Distributional Assumptions for Common
%  Value Auctions" by Michael B. Gordy, Federal Reserve Board Finance and
%  Economics Discussion Series, 1997-5, January 1997.

global alpha_ n_ tau_ beta_ 

% Default final value for x at mean plus three standard deviations
if nargin<5
   xmax=(aleph+3*sqrt(aleph))/bet;
end

% set up globals.  
alpha_=aleph; beta_=bet; tau_=tau; n_=n;

disp('BIDGIG1: Solving GIG 1st price model')
dstr='Parameters alpha=%6.4f,beta=%6.4f,tau=%2.0f,n=%2.0f';
disp(sprintf(dstr,[alpha_,beta_,tau_,n_]))
options=odeset('RelTol',1e-5,'Refine',10,'Vectorized','on');
[xx,bb]=ode23('bdotgig',[0 xmax],0,options);
