/*-----------------------------------------------------------------------
  BNLGNUXLAMBDA.C

  SYNTAX:
    (nu,lambda)=bnlgnuxlambda(x,alpha,beta,tau,n)
       x is a vector of transformed signals
       alpha is a positive scalar
       beta is a positive scalar
       tau is an integer > 1
       n is an integer > 2

  Returns nu and x*lambda of the same dimensions as x using the BNLG model.

  Requires nulambda.h.
-----------------------------------------------------------------------*/
#include <math.h>
#include "mex.h"
#include "nulambda.h"
#define betafunc(a,b) exp(lgamma(a)+lgamma(b)-lgamma(a+b))

/* BNLGNuXLambda function */
void bnlgnuxlambda(double *nuvec, double *xlambdavec, double *x, 
              double alpha, double beta, int tau,int n, int length) {
 double thetanum,thetaden,thetaden2,*c1,*c2,*poly,const1,const2,
   thetalimnum,thetalimden,thetalimden2,s;
 int i,limitform=0,xnear0;
 c1=(double *)calloc(((n-1)*(tau-1)+1),sizeof(double));
 c2=(double *)calloc(((n-2)*(tau-1)+1),sizeof(double));
 poly=(double *)calloc(tau,sizeof(double));
 /* Define e_m(z) */
 *poly=1;
   for (i=1;i<tau;i++)
     *(poly+i)=(*(poly+i-1))/i;
 /* Define c(m,n) coefficients on e_m(z)^n */
   if ((n-1)==0)
     *c1=1;
   else
     poly_exp(c1,poly,n-1,tau-1);
   if ((n-2)==0)
     *c2=1;
   else
     poly_exp(c2,poly,n-2,tau-1);
   for (i=0;i<length;i++) {
     if ((*(x+i))!=0) {
       /* s is the untransformed gamma signal */
       s=-log(*(x+i));  
       thetanum=lntheta_c(s,alpha+1,beta,tau,n-2,n,c2);
       thetaden=lntheta_c(s,alpha,beta,tau,n-2,n,c2);
       *(nuvec+i)=exp(thetanum-thetaden);
    /* Unnecessary to calculate lambda under 2nd price rule */
       if (xlambdavec!=NULL) {
          thetaden2=lntheta_c(s,alpha,beta,tau,n-1,n,c1);
	  *(xlambdavec+i)=exp(thetaden-thetaden2-lgamma(tau))*
	     (n-1)*pow(tau,tau)*pow(s,tau-1);
       }
     }
    /* Special case of x==0 */
     else {
       *(nuvec+i)=0;
       if (xlambdavec!=NULL)
	 *(xlambdavec+i)=0;
     }
   }
}

/*--------------------------------mexFunction--------------------------------*/
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]) {
  double *nuvec,*xlambdavec,*x,alpha,beta,t1,n1;
  int tau,n,i,length;
  if (nrhs!=5)
    mexErrMsgTxt("Error. Syntax is bnlgnuxlambda(x,alpha,beta,tau,n).");
  x=mxGetPr(prhs[0]);
  length=mxGetM(prhs[0]);
  alpha=mxGetScalar(prhs[1]);
  if (alpha<=0)
    mexErrMsgTxt("Error: alpha must be positive.");
  beta=mxGetScalar(prhs[2]);
  if (beta<=0)
    mexErrMsgTxt("Error: beta must be positive.");
  tau=mxGetScalar(prhs[3])+.5;
  if (tau<1)
    mexErrMsgTxt("Error: tau must be greater than or equal to one.");
  n=mxGetScalar(prhs[4])+.5;
  if (n<2)
    mexErrMsgTxt("Error: n must be greater than or equal to two.");
  plhs[0]=mxCreateDoubleMatrix(length,1,mxREAL);
  nuvec=mxGetPr(plhs[0]);
  if (nlhs==2) {
    plhs[1]=mxCreateDoubleMatrix(length,1,mxREAL);
    xlambdavec=mxGetPr(plhs[1]);
  }
  else
    xlambdavec=NULL;
  bnlgnuxlambda(nuvec,xlambdavec,x,alpha,beta,tau,n,length);
  return;
}
