/*--------------------------------------------------------------------------
  PSI.C: PSI for GIG and GHG specifications.

  SYNTAX:
   psi=psi(s,a,b,tau,m,n)
       s is a vector of raw signals
       alpha is a positive scalar
       beta is a positive scalar
       tau is an integer > 1
       m is an integer >=0 and <= n
       n is an integer >= 2

  Returns psi of the same dimensions as s.

  Requires header file nulambda.h.
--------------------------------------------------------------------------*/
#include <math.h>
#include "mex.h"
#include "nulambda.h"

/*--------------------------------mexFunction--------------------------------*/
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]) {
  double *s,a,b,*c,*poly,*answer;
  int length,i,tau,m,n;
  if (nrhs!=6)
    mexErrMsgTxt("Error. Syntax is psi(s,a,b,tau,m,n).");
  s=mxGetPr(prhs[0]);
  a=mxGetScalar(prhs[1]);
  b=mxGetScalar(prhs[2]);
  tau=mxGetScalar(prhs[3])+.5;
  if (tau<1)
    mexErrMsgTxt("Error: tau must be greater than or equal to one.");
  m=mxGetScalar(prhs[4])+.5;
  n=mxGetScalar(prhs[5])+.5;
  if (m<0 | m>n)
    mexErrMsgTxt("Error: m,n must satisfy 0<=m<=n.");
  length=mxGetM(prhs[0]);
  plhs[0]=mxCreateDoubleMatrix(length,1,mxREAL);
  answer=mxGetPr(plhs[0]);
  c=(double *)calloc((m*(tau-1)+1),sizeof(double));
  poly=(double *)calloc(tau,sizeof(double));
  /* Define e_m(z) */
  *poly=1;
  for (i=1;i<tau;i++)
      *(poly+i)=(*(poly+i-1))/i;
  if (m==0)
    *c=1;
  else
    poly_exp(c,poly,m,tau-1);
  for (i=0;i<length;i++)
    *(answer+i)=psi_c(*(s+i),a,b,tau,m,n,c);
  return;
}
